@@ -57,8 +57,8 @@ typedef struct {
 
 GtkWidget *gnomecard_canvas;
 static GnomeCanvasItem *cardname, *fullname, *workphone, *homephone;
-static GnomeCanvasItem *cardname_box, *phone_box, *postal_box, *memo_box;
-static GnomeCanvasItem *email, *url, *org, *title, *memos;
+static GnomeCanvasItem *cardname_box, *phone_box, *postal_box, *categories_box, *memo_box;
+static GnomeCanvasItem *email, *url, *org, *title, *categories, *memos;
 static CanvasAddressItem homeaddr, workaddr;
 static GnomeCanvasGroup *root;
 
@@ -70,7 +70,6 @@ gnomecard_canvas_new(void)
 	GtkWidget *canvas;
 	gdouble ypos, x1, x2, y1, y2;
 	GtkStyle *style;
-	GnomeCanvasItem *item;
 	gint i;
         GdkFont *cardname_font, *title_font, *canvas_font, *addr_font, *comment_font; 
 
@@ -400,6 +399,38 @@ gnomecard_canvas_new(void)
 						  NULL);
 
 
+	/* categories */
+	ypos += LIST_SPACING;
+	categories_box = gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
+			       "x1", 5.0,
+			       "y1", ypos,
+			       "x2", (double) (CANVAS_WIDTH - 6.0),
+			       "y2", (double) ypos+20,
+			       "fill_color", HEADER_BOX_COLOR,
+			       "outline_color", HEADER_BOX_COLOR,
+			       "width_pixels", 0,
+			       NULL);
+
+	gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
+				      "text", _("Categories"),
+				      "x", 10.0,
+				      "y", ypos+10,
+				      "fontset",  TITLE_FONTSET,
+				      "anchor", GTK_ANCHOR_WEST,
+				      "fill_color", HEADER_TEXT_COLOR,
+				      NULL);
+
+
+	ypos += 30;
+	categories = gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
+				      "text", "",
+				      "x", 5.0,
+				      "y", ypos,
+				      "fontset", CANVAS_FONTSET,
+				      "anchor", GTK_ANCHOR_WEST,
+				      "fill_color", BODY_TEXT_COLOR,
+				      NULL);
+
 	/* memo(s) */
 	ypos += LIST_SPACING;
 	memo_box = gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
@@ -474,7 +505,8 @@ void gnomecard_clear_canvas(void)
 		gnomecard_canvas_text_item_set(workaddr.state, "");
 		gnomecard_canvas_text_item_set(workaddr.country, "");
 		
-		/* memos */
+		/* categories and memos */
+		gnomecard_canvas_text_item_set(categories, "");
 		gnomecard_canvas_text_item_set(memos, "");
 }
 
@@ -510,6 +542,7 @@ gnomecard_update_canvas(Card *crd)
 		gnome_canvas_item_set(cardname_box, "x2", width, NULL);
 		gnome_canvas_item_set(phone_box, "x2", width, NULL);
 		gnome_canvas_item_set(postal_box, "x2", width, NULL);
+		gnome_canvas_item_set(categories_box, "x2", width, NULL);
 		gnome_canvas_item_set(memo_box, "x2", width, NULL);
 	}
 	
@@ -641,6 +674,12 @@ gnomecard_update_canvas(Card *crd)
 		gnomecard_canvas_text_item_set(workaddr.country, "");
 	}
 	
+	/* categories */
+	if (crd->categories.str)
+		gnomecard_canvas_text_item_set(categories, crd->categories.str);
+	else
+		gnomecard_canvas_text_item_set(categories, "");
+	
 	/* memos */
 	if (crd->comment.str)
 		gnomecard_canvas_text_item_set(memos, crd->comment.str);
